﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace DecisioLinqEntity.ObjectModel
{
    /// <summary>
    /// Modéle des destinations d'une version
    /// </summary>   
    [System.Runtime.Serialization.DataContract]
    [System.ServiceModel.XmlSerializerFormat]
    public class DESTINATION_MODEL
    {

        public DESTINATION_MODEL()
        {
            this.CHEMIN_MODEL = new List<CHEMIN_MODEL>(50);
            this.COUT_TRANCHE = new List<COUT_TRANCHE_MODEL>(50);
            this.COUT_TRANCHE_GROUPAGE = new List<COUT_TRANCHE_MODEL>(50);
        }
    
        /// <summary>
        /// Cout de dégroupage consolidé par palette
        /// </summary>
        public Nullable<decimal> COUT_AGE_DEG_PAL1_CONSOLIDE { get; set; }
        /// <summary>
        /// Non utilisé : Tarif retour embalage
        /// </summary>
        public Nullable<decimal> TARIF_RETOUR_EMB { get; set; }
        /// <summary>
        /// Séquence oracle de la version tarifaire
        /// </summary>
        public int SEQ_VERSION_TARIF { get; set; }
        /// <summary>
        /// code du département sur 4 caractéres
        /// </summary>
        public string PDEP { get; set; }    
        /// <summary>
        /// Date de mise à jour de la destination
        /// </summary>
        public Nullable<System.DateTime> DAT_DMAJ { get; set; }
        /// <summary>
        /// Code de l'enseigne sur 4 caractéres 
        /// </summary>
        public string COD_ENSEIGNE { get; set; }
        /// <summary>
        /// Catégorie de température
        /// <para>FR : Frais</para>
        /// <para>SU : Surgelée</para>
        /// <para>IN : Industriel</para>
        /// </summary>
        public string CAT_TEMP { get; set; }
        /// <summary>
        /// Libélé de l'enseigne
        /// </summary>
        public string LIB_ENSEIGNE { get; set; }
        /// <summary>
        /// Code de l'établissement sur 6 caractéres   
        /// </summary>
        public string COD_ETAB { get; set; }
        /// <summary>
        /// Libélé de l'établissement
        /// </summary>
        public string LIB_ETAB { get; set; }
        /// <summary>
        /// Numéro du Sous Type de la destination
        ///<para>1= detail</para>
        ///<para>2=détail Haute montagne</para>
        ///<para>3= cible gms</para>
        ///<para>4= cible hgms</para>      
        /// </summary>
        public short NUM_SOUS_TYP { get; set; }
        /// <summary>
        /// Non utilisé
        /// </summary>
        public string DEST_AVEC_SOL_AUT { get; set; }
        /// <summary>
        ///% d'écart du tarif modifié par rapport à celui d'origine 
        /// </summary>
        public Nullable<decimal> ECART_SOL_PLAN { get; set; }
        /// <summary>
        /// Libélé de la région administrative
        /// </summary>
        public string LIB_REG_ADM { get; set; }
        /// <summary>
        /// Code de la ville sur 3 caractéres
        /// </summary>
        public string CODE_LOC { get; set; }   
        /// <summary>
        /// Libélé de la ville
        /// </summary>
        public string LIB_LOC { get; set; }
        /// <summary>
        /// Représente le % des chemins fait en direct ( Agence départ= agence dégroupeur)
        /// </summary>
        public decimal Pourc_Direct { get; set; }
        /// <summary>
        /// <para> 1= CIBLE</para>
        /// <para> 2= DETAIL</para>      
        /// </summary>
        public string CODE_TYP_DEST { get; set; }
        /// <summary>
        /// <para> CIBLE</para>
        /// <para> DETAIL</para>      
        /// </summary>
        public string LIB_TYP_DEST { get; set; }
        /// <summary>
        /// Libélé du sous tyope
        /// <para> PF GMS</para>
        /// <para> PF HGMS</para>
        /// <para> DETAIL</para>  
        ///  <para> HM</para>
        /// </summary>
        public string LIB_SOUS_TYPE { get; set; }
        /// <summary>
        /// séquence oracle de la destination
        /// </summary>
        public int SEQ_DESTINATION { get; set; }
        /// <summary>
        /// Permet de savoir si une destination est réel ou non (Non réel = destination ajoutée 
        /// manuellement pendant la génération des destinations)
        /// </summary>
        public short IS_AUTO_ADDED { get; set; }
        /// <summary>
        /// Code sur 2 caractères du pays de destination
        /// </summary>
        public string COD_PAYS_DEST { get; set; }
        /// <summary>
        /// Cout camion complet indexé au gasoil prenant en compte les 20 minutes d'heure chauffeur
        /// </summary>
        public decimal COUT_CAMION_LH { get; set; }
        /// <summary>
        /// Cout camion complet indexé au gasoil prenant en compte les 20 minutes d'heure chauffeur
        /// </summary>
        public decimal COUT_CAMION_COMPLET{ get; set; }
        /// <summary>
        /// à partir de cette limite de palette le calcul des grilles completes passe sur le semi-lot
        /// </summary>
        public int PAL_FIN_GROUPAGE { get; set; }
        /// <summary>
        /// Représente la palette ou débute le calcul d'un tarif de camion complet
        /// </summary>
        public int PAL_COMPLET { get; set; }
        /// <summary>
        /// Indique si la destination comporte des erreurs de tarif
        /// <para>0= bon</para>
        /// <para>1= Erreur ayant un impact faible sur le tarif</para>
        /// <para>2= Erreur ayant un impact fort sur le tarif</para>
        /// </summary>
        public short IS_ERROR { get; set; }
        /// <summary>
        /// Marge global du complet
        /// </summary>
        public decimal MARGE_COMPLET { get; set; }  
        /// <summary>
        /// Liste des chemins associés à la destination
        /// </summary>
        public  List<CHEMIN_MODEL> CHEMIN_MODEL { get; set; }
        /// <summary>
        /// Liste des tarifs associés à la destination
        /// </summary>
        public  List<COUT_TRANCHE_MODEL> COUT_TRANCHE { get; set; }
        /// <summary>
        /// Sauvegarde des coûts tranche groupage pour pouvoir les restaurer en cas de changement
        /// de la limite de groupage pour les grilles 33 palettes
        /// </summary>
        public  List<COUT_TRANCHE_MODEL> COUT_TRANCHE_GROUPAGE { get; set; }
      
    }
}
